{ ------------------------------------------------------------ }
{ (C)2006-7 Blue Chip Technology Ltd.  All Rights Reserved.    }
{ ------------------------------------------------------------ }
{ NOTE: This code is still at a development stage and may not  }
{       be bug free.                                           }
{ ------------------------------------------------------------ }
{                                                              }
{  FileName  : $Workfile::                                   $ }
{                                                              }
{  Release   : 1.00                                          $ }
{                                                              }
{  Contents  : This file contains the implementation of the    }
{              Delphi header file for accessing the functions  }
{              exported by the PCI data acquisition card API.  }
{                                                              }
{  History   :                                                 }
{  $Revision::                                               $ }
{  $Author::                                                 $ }
{  $Modtime::                                                $ }
{  $History::                                                $ }
{                                                              }
{ ------------------------------------------------------------ }

{ ------------------------------------------------------------ }
{ Define the unit name.                                        }
{ ------------------------------------------------------------ }

unit bluechip;

{ ------------------------------------------------------------ }
{ Interface section.                                           }
{ ------------------------------------------------------------ }

interface

{ ------------------------------------------------------------ }
{ Define the BCT specific types that are used by the driver.   }
{ ------------------------------------------------------------ }

type
  BCT_INT8 = Char;
  BCT_INT16 = SmallInt;
  BCT_INT32 = LongInt;
  BCT_BYTE = Byte;
  BCT_WORD = Word;
  BCT_DWORD = LongWord;

  BCT_PBYTEBUFFER = BCT_BYTE;
  PBCT_BYTE = ^BCT_BYTE;


{ ------------------------------------------------------------ }
{ Driver constants.                                            }
{ ------------------------------------------------------------ }

const
  P8254_CNTR_CTRL_MASK =  $C0;
  P8254_CNTR_DATA_MASK =  $03;
  P8254_CNTR_SHIFT = $06;

  P8254_COUNTER0 = $00;
  P8254_COUNTER1 = $40;
  P8254_COUNTER2 = $80;
  P8254_READBACK = $C0;

  P8254_LATCH = $00;
  P8254_LSB = $10;
  P8254_MSB = $20;
  P8254_16BITS = $30;

  P8254_MODE0 = $00;
  P8254_MODE1 = $02;
  P8254_MODE2 = $04;
  P8254_MODE3 = $06;
  P8254_MODE4 = $08;
  P8254_MODE5 = $0A;

  P8254_BINARY_COUNTER = $00;
  P8254_BCD_COUNTER = $01;

  { Interrupt direction is Bit 0 }
  BCT_CLK_INTERRUPT_MASK = $01;
  BCT_CLK_INTERRUPT_LOW = $00;
  BCT_CLK_INTERRUPT_HIGH = $01;

  { Source is bits 1 and 2 }
  BCT_CLK_SRC_MASK = $06;
  BCT_CLK_SRC_SHIFT = $01;
  BCT_CLK_SRC_ONBOARD = $00;
  BCT_CLK_SRC_PORT1 = $02;
  BCT_EXTERN_COUNTER_INPUT1 = $02;
  BCT_CLK_SRC_CHAIN = $04;
  BCT_CLK_SRC_PORT2 = $06;
  BCT_EXTERN_COUNTER_INPUT2 = $06;

  { Enable is bits 3 and 4 }
  BCT_CLK_ENABLE_MASK = $0C;
  BCT_CLK_ENABLE_SHIFT = $03;
  BCT_CLK_ENABLED = $00;
  BCT_CLK_ENABLE_PORT1 = $04;
  BCT_CLK_ENABLE_PORT2 = $08;
  BCT_CLK_ENABLE_PORT3 = $0C;

  { Clear masks for PCIPIO Clock Control Registers }
  PCIPIO_CTRLA_MASK_CLK0 = $43;
  PCIPIO_CTRLB_MASK_CLK0 = $30;
  PCIPIO_CTRLA_MASK_CLK1 = $0C;
  PCIPIO_CTRLB_MASK_CLK1 = $4C;
  PCIPIO_CTRLA_MASK_CLK2 = $30;
  PCIPIO_CTRLB_MASK_CLK2 = $83;

  { Clear masks for PCIDIO Clock Control Registers }
  PCIDIO_CTRLA_MASK_CLK0 = $43;
  PCIDIO_CTRLB_MASK_CLK0 = $01;
  PCIDIO_CTRLA_MASK_CLK1 = $0C;
  PCIDIO_CTRLB_MASK_CLK1 = $42;
  PCIDIO_CTRLA_MASK_CLK2 = $30;
  PCIDIO_CTRLB_MASK_CLK2 = $84;

  { Clear masks for PCIADC Clock Control Registers (only 1) }
  PCIADC_CTRL_MASK_CLK0 = $00;
  PCIADC_CTRL_MASK_CLK1 = $03;
  PCIADC_CTRL_MASK_CLK2 = $0C;

  { ADC - AIN Control Codes }
  PCIADC_AIN_CHANNEL_MASK = $f0;
  PCIADC_AIN_CHANNEL_SHIFT = 4;
  PCIADC_AIN_GAIN_MASK = $0c;
  PCIADC_AIN_GAIN_SHIFT = 2;
  PCIADC_AIN_MODE_MASK = $03;
  PCIADC_AIN_MODE_SHIFT = 0;

  PCIADC_AIN_GAIN_1 = $00;
  PCIADC_AIN_GAIN_10 = $01;
  PCIADC_AIN_GAIN_100 = $02;
  PCIADC_AIN_GAIN_1000 = $03;

  PCIADC_IN_GAIN1_SETTLE = 23; { microseconds }
  PCIADC_IN_GAIN10_SETTLE = 24; { microseconds }
  PCIADC_IN_GAIN100_SETTLE = 100; { microseconds }
  PCIADC_IN_GAIN1000_SETTLE = 1000; { microseconds }

  PCIADC_AIN_MODE_SINGLE = $00;
  PCIADC_AIN_MODE_DIFFERENTIAL = $01;
  PCIADC_AIN_MODE_CALIB_ZERO = $02;
  PCIADC_AIN_MODE_CALIB_FSD = $03;
  PCIADC_AIN_MULTI_CHANNEL = $80; { used by user apps }

  PCIADC_AIN_BUSY = $01;
  PCIADC_AIN_FIFO_EMPTY = $02;
  PCIADC_AIN_FIFO_HF = $04;
  PCIADC_AIN_FIFO_FULL = $08;
  PCIADC_AIN_HFIFO_SIZE = 1024; { bytes }

  PCIADC_AIN_AUTOSEL = $01;
  PCIADC_AIN_LEVEL_TRIGGER = $02;
  PCIADC_AIN_CONVERT_NONE = $03; { AND to clear}
  PCIADC_AIN_CONVERT_SOFTWARE = $04; { or TO SET}
  PCIADC_AIN_CONVERT_PC0 = $08; { or TO SET}
  PCIADC_AIN_CONVERT_PC3 = $0c; { or TO SET}
  PCIADC_AIN_CONVERT_COUNTER0 = $10; { or TO SET}
  PCIADC_AIN_CONVERT_COUNTER1 = $14; { or TO SET}
  PCIADC_AIN_CONVERT_COUNTER2 = $18; { or TO SET}
  PCIADC_AIN_CONVERT_NOTUSED = $1c; { or TO SET}


{ ------------------------------------------------------------ }
{ DLL Error Codes.                                             }
{ ------------------------------------------------------------ }

  BCT_OK = 0;
  BCTERR_BOARD_BUSY = 1;
  BCTERR_BOARD_NOT_REQUESTED = 2;
  BCTERR_BOARD_ALREADY_REQUESTED = 3;
  BCTERR_NO_GLOBAL_MEMORY = 4;
  BCTERR_TOO_MANY_BOARDS = 5;
  BCTERR_GAINS_NOT_SUPPORTED = 6;
  BCTERR_INVALID_GAIN_VALUE = 7;
  BCTERR_NO_ANALOG_CHANNELS = 8;
  BCTERR_CHANNEL_NOT_ANALOG = 9;

  BCTERR_INVALID_RANGE = 10;
  BCTERR_NO_ANALOG_INPUTS = 11;
  BCTERR_CHANNEL_NOT_ANALOG_INPUT = 12;
  BCTERR_NULL_POINTER = 13;
  BCTERR_NO_ANALOG_OUTPUTS = 14;
  BCTERR_CHAN_NOT_ANALOG_OUTPUT = 15;
  BCTERR_VALUE_OUT_OF_RANGE = 16;
  BCTERR_ILLEGAL_NUM_CHANS = 17;
  BCTERR_NO_IRQ_AVAILABLE = 18;
  BCTERR_ILLEGAL_CHANS_IN_ARRAY = 19;

  BCTERR_ILLEGAL_NUM_SCANS = 20;
  BCTERR_LOST_DATA_IN_ISR = 21;
  BCTERR_ILLEGAL_FREQ = 22;
  BCTERR_NO_PROG_DIGITAL = 23;
  BCTERR_INVALID_CHARS = 24;
  BCTERR_INVALID_NUM_CHARS = 25;
  BCTERR_PORT_NOT_BIDIRECTIONAL = 26;
  BCTERR_NOT_DIGITAL_INPUT = 27;
  BCTERR_ILLEGAL_PORT = 28;
  BCTERR_PORT_NOT_INPUT = 29;

  BCTERR_ILLEGAL_BIT = 30;
  BCTERR_NOT_DIGITAL_OUTPUT = 31;
  BCTERR_ILLEGAL_DIGOUT_VALUE = 32;
  BCTERR_PORT_NOT_OUTPUT = 33;
  BCTERR_NO_COUNTERS = 34;
  BCTERR_INVALID_COUNTER = 35;
  BCTERR_INVALID_REF_FREQ = 36;
  BCTERR_INVALID_OUTPUT_FREQ = 37;
  BCTERR_NOT_WATCHDOG = 38;
  BCTERR_UNRECOGNISED_BOARD = 39;

  BCTERR_INVALID_BASEADDR = 40;
  BCTERR_INVALID_IRQ = 41;
  BCTERR_INVALID_DMACHAN = 42;
  BCTERR_NO_DATA = 43;
  BCTERR_STILL_ACQUIRING = 44;
  BCTERR_NO_DMA_AVAILABLE = 45;
  BCTERR_DMA_IN_USE = 46;
  BCTERR_BUFFER_TOO_SMALL = 47;
  BCTERR_INVALID_MODE_VALUE = 48;
  BCTERR_HARDWARE_MISSING = 49;

  BCTERR_UNSUPPORTED_OS = 50;
  BCTERR_GETSERIALNO_FAILED = 51;
  BCTERR_FAILED_RELEASEBOARDID = 52;
  BCTERR_INVALID_SERIALNO = 53;
  BCTERR_UNRECOGNISED_DEVICECODE = 54;
  BCTERR_UNRECOGNISED_PORTCODE = 55;
  BCTERR_UNRECOGNISED_DEVICE = 56;
  BCTERR_FAILEDCLOSE = 57;
  BCTERR_READPORT_FAILED = 58;
  BCTERR_WRITEPORT_FAILED = 59;

  BCTERR_INIT8255MODES_FAILED = 60;
  BCTERR_NTDRIVER_DEVICESOUTOFORDER = 61;
  BCTERR_DEVICECODENOTFOUND = 62;
  BCTERR_DEVICEOPEN = 63;
  BCTERR_INVALID8255MODE = 64;
  BCTERR_INVALIDIODIR = 65;
  BCTERR_INVALID_BITNO = 66;
  BCTERR_INVALID_BITSET = 67;
  BCTERR_WRITEBIT_FAILED = 68;
  BCTERR_INVALID_PACERCLOCK = 69;

  BCTERR_NOPACERCLOCK = 70;
  BCTERR_PACERCLOCKINUSE = 71;
  BCTERR_INITPACER_FAILED = 72;
  BCTERR_STOPPACER_FAILED = 73;
  BCTERR_ENABLEINTERUPT_FAILED = 74;
  BCTERR_INITCLOCK_FAILED = 75;
  BCTERR_UNEXPECTED_CLOCKNO = 76;
  BCTERR_UNSUPPORTED_BOARD = 77;
  BCTERR_ADDPACER_FAILED = 78;
  BCTERR_PACER_CLOCK_HANDLES_INUSE = 79;

  BCTERR_PACER_NOT_INITIALISED = 80;
  BCTERR_INVALID_INTERRUPT_INDEX = 81;
  BCTERR_FAILED_ENABLE_INTERRUPT = 82;
  BCTERR_FAILED_ADD_ACTION = 83;
  BCTERR_DISABLEINTERUPT_FAILED = 84;
  BCTERR_CANCELLED = 85;
  BCTERR_FAILED_PROGRAM_CNTRLCTRL = 86;
  BCTERR_INVALID_BYTECOUNT = 87;
  BCTERR_FAILED_MAP_BUFFER = 88;
  BCTERR_FAILED_LOCK_BUFFER = 89;

  BCTERR_FAILED_MAP_BUFFER_SYS = 90;
  BCTERR_INTERNAL_DRIVER_ERROR = 91;
  BCTERR_FAILED_CREATE_OVERLAP_EVENT = 92;
  BCTERR_FAILED_RESET_OVERLAP = 93;
  BCT_IO_PENDING = 94;
  BCTERR_WAIT_FAILED = 95;
  BCTERR_ALLOCATE_FAILED = 96;
  BCTERR_RELEASE_FAILED = 97;
  BCTERR_INVALID_IO_DIRECTION = 98;
  BCTERR_INIT_ISODIG_MODES_FAILED = 99;

  BCT_NOTIMPLEMENTED = 100;
  BCTERR_INVALID_DEVICE_NUMBER = 101;
  BCTERR_HANDLER_ABORTED = 102;
  BCTERR_FAILED_CLEAR_HANDLER = 103;
  BCTERR_UNSUPPORTED_8255_MODE = 104;
  BCTERR_UNSUPPORTED_A_DIRECTION = 105;
  BCTERR_UNSUPPORTED_B_DIRECTION = 106;
  BCTERR_UNSUPPORTED_C_DIRECTION = 107;
  BCTERR_UNSUPPORTED_ISODIG_MODE = 108;
  BCTERR_BLOCKIO_NOT_SUPPORTED = 109;

  BCTERR_ILLEGAL_COMBINATION = 110;
  BCTERR_MISSING_OPTION = 111;
  BCTERR_INITAOUTMODES_FAILED = 112;
  BCTERR_INVALID_CHANNEL_NUMBER = 113;
  BCTERR_INPUT_CONVERSION_TIMEOUT = 114;
  BCTERR_FIFO_ERROR = 115;
  BCTERR_AUTOSEL_NOT_SUPPORTED = 116;
  BCTERR_INVALID_SAMPLE_FREQ = 117;
  BCTERR_READBLOCK_FAILED = 118;
  BCTERR_PACER_CLOCK_HANDLE_INUSE = 119;

  BCTERR_FIFO_OVERFLOW = 120;
  BCTERR_AUTOCAL_NOT_SUPPORTED = 121;
  BCTERR_AUTOCAL_FAILED = 122;
  BCTERR_INVALID_COUNTER_VALUE = 123;
  BCTERR_INVALID_COUNTER_INPUT = 124;
  BCTERR_SETWDT_FAILED = 125;
  BCTERR_READWDT_FAILED = 126;
  BCTERR_WDTACCESS_TOOSOON = 127;
  BCTERR_ACCESS_WDT_FAILED = 128;
  BCTERR_INVALID_WDT_OPERATION = 129;

  BCTWARN_OUTPUT_VALUES_CLIPPED = 200;

  BCT_RUNNING = 300;
  BCT_FINISHED = 301;
  BCT_IDLE = 302;
  BCT_OVERRUN = 303;

  BCTERR_PCI_BIOS_NOT_PRESENT = 401;
  BCTERR_PCI_BOARD_NOT_FOUND = 402;
  BCTERR_PCI_ISR_NOT_AVAIL = 403;
  BCTERR_PCI_ISR_FUNCTION_ACTIVE = 404;
  BCTERR_PCI_INVALID_CLKSRC = 405;
  BCTERR_PCI_INVALID_CLKTYPE = 406;

{ ------------------------------------------------------------ }
{ Interrupt handler definitions.                               }
{ ------------------------------------------------------------ }
  MAX_INTERRUPTS = 8;
  MAX_INTERRUPT_ACTIONS = 5;

  PCIPIO_MAX_INTERRUPTS = 7;
  PCIPIO_INTERRUPT_MASK = $7;
  PCIPIO_INT_AC0 = 0;
  PCIPIO_INT_AC3 = 1;
  PCIPIO_INT_BC0 = 2;
  PCIPIO_INT_BC3 = 3;
  PCIPIO_INT_TIMER0 = 4;
  PCIPIO_INT_TIMER1 = 5;
  PCIPIO_INT_TIMER2 = 6;

  PCIDIO_MAX_INTERRUPTS = 5;
  PCIDIO_INTERRUPT_MASK = $1;
  PCIDIO_INT_ISOLOW = 0;
  PCIDIO_INT_ISOHIGH = 1;
  PCIDIO_INT_TIMER0 = 2;
  PCIDIO_INT_TIMER1 = 3;
  PCIDIO_INT_TIMER2 = 4;

  PCIADC_MAX_INTERRUPTS = 8;
  PCIADC_INTERRUPT_MASK = $ff;
  PCIADC_INT_PC0 = 0;
  PCIADC_INT_PC3 = 1;
  PCIADC_INT_TIMER0 = 2;
  PCIADC_INT_TIMER1 = 3;
  PCIADC_INT_TIMER2 = 4;

  PCIADC_INT_ADC_NOT_BUSY = 5;
  PCIADC_INT_FIFO_NOT_EMPTY = 6;
  PCIADC_INT_FIFO_HALF_FULL = 7;
  PCIWDT_MAX_INTERRUPTS = 3;
  PCIWDT_INTERRUPT_MASK = $0;
  PCIWDT_ENA_WATCHDOG = 0;
  PCIWDT_INT_EXTERNAL = 1;
  PCIWDT_INT_LM78 = 2;
  PCIWDT_INT_WATCHDOG = 3;


{ ------------------------------------------------------------ }
{ Supported board types.                                       }
{ ------------------------------------------------------------ }

type
  BCT_BOARDTYPE = (
    UNKNOWN_BOARD,
    DIP_24,
    DOP_24,
    DIO_48,
    PIO_96,
    RB_8,
    PIO_48DB,
    PIO_144P,
    DCM_16,
    AIP_24,
    AOP_8,
    AIP_8D,
    AOP_12D,
    ADC_42,
    ADC_44D,
    WD_1,
    DIO_32D,
    PCI_PIO,
    PCI_DIO,
    PCI_ADC,
    PCI_WDT  );

{ ------------------------------------------------------------ }
{ Supported device types.                                      }
{ ------------------------------------------------------------ }

type
  BCT_DEVICETYPE = (
    BCT_8255,
    BCT_8254,
    BCT_ISODIG,
    BCT_AIN,
    BCT_AOUT,
    BCT_WDT  );

const
  BCT_PORT_A = 0;
  BCT_PORT_B = 1;
  BCT_PORT_C = 2;
  BCT_CLK_0 = 0;
  BCT_CLK_1 = 1;
  BCT_CLK_2 = 2;
  ISO_DIG_LOW8 = 0;
  ISO_DIG_HIGH8 = 1;
  ISO_DIG_ALL16 = 2;
  BCT_CHAN_0 = 0;
  BCT_CHAN_1 = 1;
  BCT_CHAN_2 = 2;
  BCT_CHAN_3 = 3;
  BCT_AOUT_VOLTAGE = $01;
  BCT_AOUT_CURRENT = $02;

type
  BCT_8255_MODES = (
    MODE_0,
    MODE_1,
    MODE_2,
    MODE_20,
    MODE_21  );

type
  BCT_DIRECTIONS = (
    INPUT,
    OUTPUT,
    BIDI,
    NOCARE,
    ININ,
    OUTOUT,
    INOUT,
    OUTIN  );

type
   BCT_HANDLER = (
    NO_HANDLER,
    READ_PACER,
    BLOCK_SINGLE_READ,
    BLOCK_DOUBLE_BUFFER_READ,
    BLOCK_SINGLE_WRITE,
    BLOCK_DOUBLE_BUFFER_WRITE,
    BLOCK_REPEATED_WRITE  );

type
  _BCT_WDT_SETDATA = record
    IN0_High_3_3V: BCT_BYTE;
    IN0_Low_3_3V: BCT_BYTE;
    IN1_High_5V: BCT_BYTE;
    IN1_Low_5V: BCT_BYTE;
    IN2_High_12V: BCT_BYTE;
    IN2_Low_12V: BCT_BYTE;
    IN3_High: BCT_BYTE;
    IN3_Low: BCT_BYTE;
    IN4_High: BCT_BYTE;
    IN4_Low: BCT_BYTE;
    IN5_High_Minus12V: BCT_BYTE;
    IN5_Low_Minus12V: BCT_BYTE;
    IN6_High: BCT_BYTE;
    IN6_Low: BCT_BYTE;
    OverTempHigh: BCT_BYTE;
    TempHysteresisLow: BCT_BYTE;
    Fan1Count: BCT_BYTE;
    Fan2Count: BCT_BYTE;
    Fan3Count: BCT_BYTE;
    FanRpm: BCT_BYTE;
  end {_BCT_WDT_SETDATA};
  BCT_WDT_SETDATA = _BCT_WDT_SETDATA;
  PBCT_WDT_SETDATA = ^_BCT_WDT_SETDATA;

type
  _BCT_WDT_READDATA = record
    IN0_3_3V: BCT_BYTE;
    IN1_5V: BCT_BYTE;
    IN2_12V: BCT_BYTE;
    IN3: BCT_BYTE;
    IN4: BCT_BYTE;
    IN5_Minus12V: BCT_BYTE;
    IN6: BCT_BYTE;
    Temperature: BCT_BYTE;
    Fan1Count: BCT_BYTE;
    Fan2Count: BCT_BYTE;
    Fan3Count: BCT_BYTE;
    ExternalInput: BCT_BYTE;
    InterruptStatus1: BCT_BYTE;
    InterruptStatus2: BCT_BYTE;
  end {_BCT_WDT_READDATA};
  BCT_WDT_READDATA = _BCT_WDT_READDATA;
  PBCT_WDT_READDATA = ^_BCT_WDT_READDATA;

{ Overlapped is a standard Windows "C" type and is a structure }
{ that consists of 5 32bit values.  In the Visual Basic header }
{ file this is converted to "long" types and so we need to use }
{ longint or our definition BCT_DWORD.  If this is incorrect   }
{ then it will have a knock-on effect for the size of the      }
{ BCT_HANDLE structure and the driver will then have problems. }
type
   OVERLAPPED = record
      internal : BCT_DWORD;
      internalHigh : BCT_DWORD;
      offset : BCT_DWORD;
      offsetHigh : BCT_DWORD;
      hEvent : BCT_DWORD;
    end;

{ Whilst the Handle type can be defined as a THandle.  Experience }
{ has shown that it is better to stick to a generic 32 bit type   }
{ here.                                                           }
type
  _BCT_HANDLE = record
    Handle: BCT_DWORD;
    Overlap: OVERLAPPED;
    DeviceType: BCT_DWORD;
    BoardType: BCT_DWORD;
    nPort: BCT_WORD;
    LastError: BCT_DWORD;
    NextTime: longint;
  end ;
  BCT_HANDLE = _BCT_HANDLE;
  PBCT_HANDLE = ^_BCT_HANDLE;

{ Whilst the Handle type can be defined as a THandle.  Experience }
{ has shown that it is better to stick to a generic 32 bit type   }
{ here.                                                           }
type
  _BCT_BOARD_ID = record
    Handle: BCT_DWORD;
    SerialNo: BCT_DWORD;
    DevName: Array[1..30] of Char;
    Clock0Name: Array[1..30] of Char;
    Clock1Name: Array[1..30] of Char;
    Clock2Name: Array[1..30] of Char;
    hClock0: BCT_HANDLE;
    hClock1: BCT_HANDLE;
    hClock2: BCT_HANDLE;
    Index: BCT_DWORD;
    DeviceType: BCT_DWORD;
  end ;
  BCT_BOARD_ID = _BCT_BOARD_ID;


type
  _BCT_BUFFER = record
    Length: BCT_DWORD; //ULONG;
    Sema: BCT_DWORD; //ULONG;
    Buffer: Array[1..10] of BCT_BYTE;
  end ;
  BCT_BUFFER = _BCT_BUFFER;
  PBCT_BUFFER = ^_BCT_BUFFER;

{ Index's for Pacer Commands }
Const
  PACER_STATUS = 0; { we return the status here as well }
  PACER_OP = 0; { what sort of Pacer To Add }
  PACER_SKIP_INTERRUPTS = 1; { how many Pacer interrupts to skip between ops }
  PACER_CLOCK_ID = 2; { which Board has the Pacer Clock }
  PACER_BUFFER_1 = 3; { Win32 Ptrs to Buffers }
  PACER_BUFFER_2 = 4; { WARNING, assumes a pointer is 32 bits long! }
  PACER_BUFFER_COUNT = 5; { #bytes in a buffer }

  { Both DLL and Driver remember what sort of Board we are }
  DEVICE_TYPE_PCIPIO = 41;
  DEVICE_TYPE_PCIDIO = 42;
  DEVICE_TYPE_PCIADC = 43;
  DEVICE_TYPE_PCIWDT = 44;
  DEVICE_TYPE_8254 = 51;
  DEVICE_TYPE_8255 = 52;
  DEVICE_TYPE_ISODIG = 53;
  DEVICE_TYPE_AIN = 54;
  DEVICE_TYPE_AOUT = 55;
  DEVICE_TYPE_WDT = 56;

Type WATCHDOG_OPERATION = (
    BCT_WD_WRITE_TIMEOUT,
    BCT_WD_REFRESH_TIMEOUT,
    BCT_WD_REFRESH_ENABLE_MASK,
    BCT_WD_WRITE_OUTPUT_MASK);


{ ------------------------------------------------------------ }
{ Function prototypes.                                         }
{ ------------------------------------------------------------ }

function BCTGetBoardId(var pBoardId: BCT_BOARD_ID; nDevType: BCT_BOARDTYPE; nBoard: BCT_WORD) : BCT_DWORD; stdcall;
function BCTReleaseBoardId(var pBoardId: BCT_BOARD_ID) : BCT_DWORD; stdcall;
function BCTFindSerialNo(nSerial: BCT_DWORD; var pBoardType: BCT_BOARDTYPE; var pBoard: BCT_WORD) : BCT_DWORD; stdcall;
function BCTOpen(var pHandle: PBCT_HANDLE; var pBoardId: BCT_BOARD_ID; nDevType: BCT_DEVICETYPE; nDev: BCT_WORD; nPort: BCT_WORD) : BCT_DWORD; stdcall;
function BCTClose(var pHandle: PBCT_HANDLE) : BCT_DWORD; stdcall;
function BCTInit8255Modes(var pBoardId: BCT_BOARD_ID; nDev: BCT_WORD; nMode: BCT_8255_MODES; nPortA: BCT_DIRECTIONS; nPortB: BCT_DIRECTIONS; nPortC: BCT_DIRECTIONS) : BCT_DWORD; stdcall;
function BCTInitIsoDigModes(var pBoardId: BCT_BOARD_ID; nDev: BCT_WORD; nMode: BCT_8255_MODES; nPortA: BCT_DIRECTIONS; nPortB: BCT_DIRECTIONS; nPortC: BCT_DIRECTIONS) : BCT_DWORD; stdcall;
function BCTInitAOutModes(var pBoardId: BCT_BOARD_ID; nDev: BCT_WORD; nChan0: BCT_WORD; nChan1: BCT_WORD; nChan2: BCT_WORD; nChan3: BCT_WORD) : BCT_DWORD; stdcall;
function BCTReadPort(var pHandle: PBCT_HANDLE; var nVal: BCT_BYTE) : BCT_DWORD; stdcall;
function BCTReadPort16(var pHandle: PBCT_HANDLE; var nVal: BCT_WORD) : BCT_DWORD ; stdcall;
function BCTReadPortAin(var pHandle: PBCT_HANDLE; nChan: BCT_BYTE; nGain: BCT_BYTE; nMode: BCT_BYTE; var nVal: BCT_WORD) : BCT_DWORD; stdcall;
function BCTWritePort(var pHandle: PBCT_HANDLE; nVal: BCT_BYTE) : BCT_DWORD; stdcall;
function BCTWritePort16(var pHandle: PBCT_HANDLE; nVal: BCT_WORD) : BCT_DWORD; stdcall;
function BCTWriteBit(var pHandle: PBCT_HANDLE; nBit: BCT_BYTE; nVal: BCT_BYTE) : BCT_DWORD; stdcall;
function BCTProgramCounter(var pHandle: PBCT_HANDLE; nSource: BCT_BYTE) : BCT_DWORD; stdcall;
function BCTInitPacer(var pBoardId: BCT_BOARD_ID) : BCT_DWORD; stdcall;
function BCTStartPacer(var pBoardId: BCT_BOARD_ID; nInterval: BCT_DWORD) : BCT_DWORD; stdcall;
function BCTStopPacer(var pBoardId: BCT_BOARD_ID) : BCT_DWORD; stdcall;
function BCTAddPacerFunction(var pBoardId: BCT_BOARD_ID; nOperation: BCT_HANDLER; var pVal: BCT_DWORD) : BCT_DWORD; stdcall;
function BCTAddPacerBlockIo(var pHandle: PBCT_HANDLE; var pBoardId: BCT_BOARD_ID; nOperation: BCT_WORD; var pBuffer1: BCT_BUFFER; var pBuffer2: BCT_BUFFER; nBytes: BCT_DWORD; nCount: BCT_DWORD) : BCT_DWORD; stdcall;
procedure BCTErr2Txt(Code: BCT_DWORD; txt: PChar); stdcall;
function BCTWait(var pHandle: PBCT_HANDLE; delay: BCT_DWORD) : BCT_DWORD; stdcall;
function BCTInitHandle(var pHandle: PBCT_HANDLE) : BCT_DWORD; stdcall;
function BCTAllocate(var pBctBuf: PBCT_BUFFER; Length: BCT_DWORD) : BCT_DWORD; stdcall;
function BCTRelease(var pBctBuf: PBCT_BUFFER) : BCT_DWORD; stdcall;
function BCTAcquireAPacer(var pBoardId: BCT_BOARD_ID) : BCT_DWORD; stdcall;
function BCTReleaseAPacer(var pBoardId: BCT_BOARD_ID) : BCT_DWORD; stdcall;
function BCTReadBlockAin(var pBoardId: BCT_BOARD_ID; var pHandle: PBCT_HANDLE; nChan: BCT_BYTE; nGain: BCT_BYTE; nMode: BCT_BYTE; var pBuffer: BCT_BUFFER; nSamples: BCT_DWORD; nTime: BCT_WORD) : BCT_DWORD; stdcall;
function BCTAutoCalAin(var pHandle: PBCT_HANDLE; Gain: BCT_BYTE; var MeanZero: BCT_WORD; var MeanFsd: BCT_WORD) : BCT_DWORD; stdcall;
function BCTSetWdt(var pHandle: PBCT_HANDLE; var pData: BCT_WDT_SETDATA) : BCT_DWORD; stdcall;
function BCTReadWdt(var pHandle: PBCT_HANDLE; var pData: BCT_WDT_READDATA) : BCT_DWORD; stdcall;
function BCTWatchdog(var pHandle: PBCT_HANDLE; nAction: WATCHDOG_OPERATION; var pData: BCT_BYTE) : BCT_DWORD; stdcall;
function BCTGetLastError(var pHandle: PBCT_HANDLE; var pErrCode: BCT_DWORD) : BCT_DWORD; stdcall;


{ ------------------------------------------------------------ }
{ End of interface section.                                    }
{ ------------------------------------------------------------ }
{ Implementation section.                                      }
{ ------------------------------------------------------------ }

implementation

{ ------------------------------------------------------------ }
{ Import the functions from the DLL.                           }
{ ------------------------------------------------------------ }

function BCTGetBoardId; external 'bcdll32.dll';
function BCTReleaseBoardId; external 'bcdll32.dll';
function BCTFindSerialNo; external 'bcdll32.dll';
function BCTOpen; external 'bcdll32.dll';
function BCTClose; external 'bcdll32.dll';
function BCTInit8255Modes; external 'bcdll32.dll';
function BCTInitIsoDigModes; external 'bcdll32.dll';
function BCTInitAOutModes; external 'bcdll32.dll';
function BCTReadPort; external 'bcdll32.dll';
function BCTReadPort16; external 'bcdll32.dll';
function BCTReadPortAin; external 'bcdll32.dll';
function BCTWritePort; external 'bcdll32.dll';
function BCTWritePort16; external 'bcdll32.dll';
function BCTWriteBit; external 'bcdll32.dll';
function BCTProgramCounter; external 'bcdll32.dll';
function BCTInitPacer; external 'bcdll32.dll';
function BCTStartPacer; external 'bcdll32.dll';
function BCTStopPacer; external 'bcdll32.dll';
function BCTAddPacerFunction; external 'bcdll32.dll';
function BCTAddPacerBlockIo; external 'bcdll32.dll';
procedure BCTErr2Txt; external 'bcdll32.dll';
function BCTWait; external 'bcdll32.dll';
function BCTInitHandle; external 'bcdll32.dll';
function BCTAllocate; external 'bcdll32.dll';
function BCTRelease; external 'bcdll32.dll';
function BCTAcquireAPacer; external 'bcdll32.dll';
function BCTReleaseAPacer; external 'bcdll32.dll';
function BCTReadBlockAin; external 'bcdll32.dll';
function BCTAutoCalAin; external 'bcdll32.dll';
function BCTSetWdt; external 'bcdll32.dll';
function BCTReadWdt; external 'bcdll32.dll';
function BCTWatchdog; external 'bcdll32.dll';
function BCTGetLastError; external 'bcdll32.dll';


{ ------------------------------------------------------------ }
{ End of listing.                                              }
{ ------------------------------------------------------------ }

end.
